@@ -235,13 +235,13 @@ class Binomial(Distribution):
         #sorted_dict =   collections.OrderedDict(sorted(obj_dict.items()))
         returned_string =""
         for k,v in obj_dict.items():
-            if k.equals('mean'):
+            if k == 'mean':
                 returned_string = returned_string + 'mean ' + str(v) + ','
-            if k.equals('stdev'):
+            if k == 'stdev':
                 returned_string = returned_string + 'standard deviation ' + str(v) + ','
-            if k.equals('p'):
+            if k == 'p':
                 returned_string = returned_string + 'p ' + str(v) + ','
-            if k.equals('n'):
+            if k == 'n':
                 returned_string = returned_string + 'n ' + str(v)
                                     
         return returned_string
